require 'yaml'
require 'fileutils'

namespace :i18n do
  #
  # for coding, it helps to have the english strings in separate files.
  # for translating, it helps to have a single file. This action will combine
  # the small files into one big one.
  #
  # Also, transifex insists that the files be en_US and not just en.
  # grrr. transifex is configured to automatically update from the
  # file lib/en_US.yml.
  #
  desc "combine config/locales/*.en.yml to lib/en_US.yml"
  task :bundle do
    en_yml = File.join(Rails.root, 'lib', 'en_US.yml')
    Dir.chdir('config/locales/') do
      if File.exists?(en_yml)
        File.unlink en_yml
      end
      File.open(en_yml, 'w') do |output|
        output.write("en_US:\n\n"+
          "### Do NOT edit this file directly, as all changes will be overwritten by `rake i18:bundle`\n"+
          "### Instead, make changes in the appropriate file in config/locales.\n"+
          "### Source strings in transifex are automatically updated from this file (via github url)")

        Dir.glob('*.en.yml').sort.each do |file|
          ## print separator to see where another file begins
          output.write("\n\n" + '#' * 40 + "\n" + '### ' + file + "\n")
          output.write(
            # remove the toplevel "en" key
            YAML.load_file(file)['en'].
            to_yaml.
            # prefix all lines with two spaces (we're nested below "en:")
            lines.map {|line| "  #{line}"}[
              1..-1 # << skip the first line (it's "---" and freaks out the parser if it sees it multiple times in a file)
            ].join)
        end
      end
      puts "You can now find the bundled locale yml in: #{en_yml}"
    end
  end


  # elijah: this does not actually work, but I think could be a starting point
  # for something that will work.
  desc "pull translations from transifex"
  task :download do
    Conf.enabled_languages.each do |lang|
      next unless lang == 'en'
      `curl -L --user #{Conf.transifex_user}:#{Conf.transifex_password} -X GET https://www.transifex.net/api/2/project/crabgrass/resource/master/translation/#{lang}/?file > config/locales/#{lang}.yml`
    end
  end
end
